@@ -28,7 +28,7 @@ import json
 # otherwise it dies (by isolation or overpopulation)
 
 
-###################################################################################################
+##################################################################################################
 
 class JeuDeLaVie:  # GameOfLife :)
     """
@@ -242,6 +242,12 @@ class JeuDeLaVie:  # GameOfLife :)
     def start_animation(self, interval_between_two_frames: int = 100, plot: bool = True, save: bool = False, fps: int = 30, file_name: str = None):
         """ Start the animation, by default by plotting, and no video is saved
         
+        NOTE :         
+            For saving : 
+            You need first to install ffmpeg :
+            First search : Homebrew website (https://brew.sh/)
+            Copy past the command in a Terminal
+            Then in a Terminal : brew install ffmpeg
 
         Args:
             interval_between_two_frames (int, optional):
@@ -294,11 +300,10 @@ class JeuDeLaVie:  # GameOfLife :)
         try:
             with open("save.json", "r") as f:
                 maps = json.load(f)
+            return maps
         except:
-            with open("save.json", "w") as f:
-                maps = []
-                json.dump(maps, f)
-        return maps
+            pass
+        
 
     @staticmethod
     def get_MAP():
@@ -378,6 +383,7 @@ def _assert_test(size_or_side, custom_map):
 
 ###################################################################################################
 
+custom_maps = GameOfLife.get_MAP()
 
 
 my_map_1 = np.zeros((50, 50))
@@ -386,13 +392,12 @@ my_map_2 = np.zeros((100, 100))
 my_map_1[24] = np.array([0]*20 + [1]*10 + [0]*20)
 my_map_2[35:-35, 35:-35] = np.random.randint(0, 2, (30, 30))
 
-custom_maps = GameOfLife.get_MAP()
-maps = [my_map_1, my_map_2] + custom_maps
+maps = [my_map_1, my_map_2]
 
 if __name__ == "__main__":
     from random import choice
     
     MAP = choice(maps)
 
-    game = GameOfLife(custom_map=MAP, frames=50)
-    game.start_animation(interval_between_two_frames=10)
+    game = GameOfLife(custom_map=MAP, frames=500)
+    game.start_animation(interval_between_two_frames=50)
